Tools for the Transport Data Commons
************************************

.. image:: https://readthedocs.org/projects/transport-data/badge/?version=latest
   :target: https://docs.transport-data.org/en/latest/?badge=latest
   :alt: Documentation status
.. image:: https://github.com/transport-data/tools/actions/workflows/pytest.yaml/badge.svg
   :target: https://github.com/transport-data/tools/actions/workflows/pytest.yaml
   :alt: "pytest" workflow status badge
.. image:: https://codecov.io/gh/transport-data/tools/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/transport-data/tools
   :alt: Codecov.io test coverage status badge

See the online documentation: https://docs.transport-data.org
